// Specify the URL of the CSV file
const csvUrl =
  'https://gist.githubusercontent.com/raviteja002/363b93f5da277fa8000c24795a322c07/raw/e5d03f466d3865c839b005167e9ca6d1c815ea82/sales.csv';

// Load data from the CSV file using D3
d3.csv(csvUrl)
  .then(function (data) {
    // Convert string values to numbers if needed
    data.forEach(function (d) {
      d.Year = +d.Year; // Convert Year to number
      d.Sales = +d.Sales; // Convert Sales to number
    });

    // Set up dimensions for the chart
    const width = 800;
    const height = 400;
    const margin = {
      top: 20,
      right: 20,
      bottom: 50,
      left: 50,
    };
    const innerWidth = width - margin.left - margin.right;
    const innerHeight = height - margin.top - margin.bottom;

    // Create SVG element
    const svg = d3
      .select('body')
      .append('svg')
      .attr('id', 'areachart') // Added id to select the SVG later
      .attr('width', width)
      .attr('height', height);

    // Create scales
    const xScale = d3
      .scaleLinear()
      .domain(d3.extent(data, (d) => d.Year)) // Set domain for xScale
      .range([margin.left, innerWidth]);

    const yScale = d3
      .scaleLinear()
      .domain([0, d3.max(data, (d) => d.Sales)]) // Set domain for yScale
      .range([innerHeight, margin.top]);

    // Create area generator
    const areaGenerator = d3
      .area()
      .x((d) => xScale(d.Year)) // Set x value for the area
      .y0(innerHeight)
      .y1((d) => yScale(d.Sales)); // Set y value for the area

    // Append area to SVG
    svg
      .append('path')
      .datum(data)
      .attr('fill', 'steelblue')
      .attr('d', areaGenerator);

    // Create axes
    const xAxis = d3
      .axisBottom(xScale)
      .tickFormat(d3.format('d'));
    const yAxis = d3.axisLeft(yScale);

    // Append axes to SVG
    svg
      .append('g')
      .attr('transform', `translate(0, ${innerHeight})`)
      .call(xAxis)
      // X-axis label
      .append('text')
      .attr('x', innerWidth / 2)
      .attr('y', margin.bottom - 10)
      .attr('fill', '#000')
      .style('text-anchor', 'middle')
      .text('Year'); // X-axis label

    svg
      .append('g')
      .attr('transform', `translate(${margin.left}, 0)`)
      .call(yAxis)
      // Y-axis label
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('x', -innerHeight / 2)
      .attr('y', -margin.left + 15)
      .attr('fill', '#000')
      .style('text-anchor', 'middle')
      .text('Sales'); // Y-axis label
  })
  .catch(function (error) {
    console.log('Error loading data: ', error);
  });
